@@ -925,3 +925,15 @@ def press_releases(
     path = f"press-releases/{symbol}"
     query_vars = {"apikey": apikey, "limit": limit}
     return __return_json_v3(path=path, query_vars=query_vars)
+
+
+def stock_peers(apikey: str, symbol: str) -> typing.Optional[typing.List[typing.Dict]]:
+    """
+    Query FMP /stock_peers/ API
+    :param apikey: Your API key
+    :param symbol: Company ticker
+    :return: A list of dictionaries
+    """
+    path = f"stock_peers"
+    query_vars = {"apikey": apikey, "symbol": symbol}
+    return __return_json_v4(path=path, query_vars=query_vars)
